Py4JClass (py4j-java 0.10.9.4 API)
Date: 2022-03-16

py4j.model

## Class Py4JClass

- java.lang.Object
- - py4j.model.Py4JMember
  - - py4j.model.Py4JClass

- All Implemented Interfaces:
    java.lang.Comparable<Py4JMember>

      public class Py4JClass
      extends Py4JMember

  Model of a Java class used to create a help page.

- - ### Constructor Summary

    Constructors
    Constructor and Description
    `Py4JClass(java.lang.String name, java.lang.String javadoc, java.lang.String extendType, java.util.List<java.lang.String> implementTypes, java.util.List<Py4JMethod> methods, java.util.List<Py4JField> fields, java.util.List<Py4JClass> classes)`

  - ### Method Summary

    All Methods Static Methods Instance Methods Concrete Methods
    Modifier and Type | Method and Description
    --- | ---
    `static Py4JClass` | `buildClass(java.lang.Class<?> clazz)`
    `static Py4JClass` | `buildClass(java.lang.Class<?> clazz, boolean sort)`
    `java.util.List<Py4JClass>` | `getClasses()`
    `java.lang.String` | `getExtendType()`
    `java.util.List<Py4JField>` | `getFields()`
    `java.util.List<java.lang.String>` | `getImplementTypes()`
    `java.util.List<Py4JMethod>` | `getMethods()`
    `java.lang.String` | `getSignature(boolean shortName)`

    - ### Methods inherited from class py4j.model.Py4JMember

      `compareTo, equals, getJavadoc, getName, hashCode`

    - ### Methods inherited from class java.lang.Object

      `clone, finalize, getClass, notify, notifyAll, toString, wait, wait, wait`

- - ### Constructor Detail

    - #### Py4JClass

          public Py4JClass(java.lang.String name,
                           java.lang.String javadoc,
                           java.lang.String extendType,
                           java.util.List<java.lang.String> implementTypes,
                           java.util.List<Py4JMethod> methods,
                           java.util.List<Py4JField> fields,
                           java.util.List<Py4JClass> classes)

  - ### Method Detail

    - #### buildClass

          public static final Py4JClass buildClass(java.lang.Class<?> clazz)

    - #### buildClass

          public static final Py4JClass buildClass(java.lang.Class<?> clazz,
                                                   boolean sort)

    - #### getClasses

          public java.util.List<Py4JClass> getClasses()

    - #### getExtendType

          public java.lang.String getExtendType()

    - #### getFields

          public java.util.List<Py4JField> getFields()

    - #### getImplementTypes

          public java.util.List<java.lang.String> getImplementTypes()

    - #### getMethods

          public java.util.List<Py4JMethod> getMethods()

    - #### getSignature

          public java.lang.String getSignature(boolean shortName)

      Specified by:
        `getSignature` in class `Py4JMember`